"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing
import yandex.cloud.cloudapps.workload.v1.cloud_application_pb2
import yandex.cloud.cloudapps.workload.v1.cloud_application_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class CloudApplicationServiceStub:
    """Cloud Application Service to be used by Workload software inside Cloud Application installations"""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        google.protobuf.empty_pb2.Empty,
        yandex.cloud.cloudapps.workload.v1.cloud_application_pb2.CloudApplication,
    ]
    """Get Current Application"""

    ResolveByWorkload: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudapps.workload.v1.cloud_application_service_pb2.ResolveByWorkloadRequest,
        yandex.cloud.cloudapps.workload.v1.cloud_application_service_pb2.ResolveByWorkloadResponse,
    ]
    """Resolve Cloud Application by workload"""

class CloudApplicationServiceAsyncStub:
    """Cloud Application Service to be used by Workload software inside Cloud Application installations"""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        google.protobuf.empty_pb2.Empty,
        yandex.cloud.cloudapps.workload.v1.cloud_application_pb2.CloudApplication,
    ]
    """Get Current Application"""

    ResolveByWorkload: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudapps.workload.v1.cloud_application_service_pb2.ResolveByWorkloadRequest,
        yandex.cloud.cloudapps.workload.v1.cloud_application_service_pb2.ResolveByWorkloadResponse,
    ]
    """Resolve Cloud Application by workload"""

class CloudApplicationServiceServicer(metaclass=abc.ABCMeta):
    """Cloud Application Service to be used by Workload software inside Cloud Application installations"""

    @abc.abstractmethod
    def Get(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudapps.workload.v1.cloud_application_pb2.CloudApplication, collections.abc.Awaitable[yandex.cloud.cloudapps.workload.v1.cloud_application_pb2.CloudApplication]]:
        """Get Current Application"""

    @abc.abstractmethod
    def ResolveByWorkload(
        self,
        request: yandex.cloud.cloudapps.workload.v1.cloud_application_service_pb2.ResolveByWorkloadRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudapps.workload.v1.cloud_application_service_pb2.ResolveByWorkloadResponse, collections.abc.Awaitable[yandex.cloud.cloudapps.workload.v1.cloud_application_service_pb2.ResolveByWorkloadResponse]]:
        """Resolve Cloud Application by workload"""

def add_CloudApplicationServiceServicer_to_server(servicer: CloudApplicationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class FederatedCredential(google.protobuf.message.Message):
    """A federated credential."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    FEDERATION_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_SUBJECT_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Id of the federated credential."""
    service_account_id: builtins.str
    """Id of the service account that the federated credential belongs to."""
    federation_id: builtins.str
    """ID of the workload identity federation which is used for authentication."""
    external_subject_id: builtins.str
    """Id of the external subject."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        service_account_id: builtins.str = ...,
        federation_id: builtins.str = ...,
        external_subject_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "external_subject_id", b"external_subject_id", "federation_id", b"federation_id", "id", b"id", "service_account_id", b"service_account_id"]) -> None: ...

global___FederatedCredential = FederatedCredential



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v1/image_copy_search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/ai/vision/v1/image_copy_search.proto\x12\x19yandex.cloud.ai.vision.v1\"j\n\x19ImageCopySearchAnnotation\x12\x12\n\ncopy_count\x18\x01 \x01(\x03\x12\x39\n\x0btop_results\x18\x02 \x03(\x0b\x32$.yandex.cloud.ai.vision.v1.CopyMatch\"T\n\tCopyMatch\x12\x11\n\timage_url\x18\x01 \x01(\t\x12\x10\n\x08page_url\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\tBe\n\x1dyandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;visionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.vision.v1.image_copy_search_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;vision'
  _globals['_IMAGECOPYSEARCHANNOTATION']._serialized_start=80
  _globals['_IMAGECOPYSEARCHANNOTATION']._serialized_end=186
  _globals['_COPYMATCH']._serialized_start=188
  _globals['_COPYMATCH']._serialized_end=272
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/episode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/video/v1/episode.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x82\x06\n\x07\x45pisode\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tstream_id\x18\x02 \x01(\t\x12\x0f\n\x07line_id\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x06 \x01(\t\x12.\n\nstart_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inish_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64vr_seconds\x18\t \x01(\x03\x12J\n\x11visibility_status\x18\n \x01(\x0e\x32/.yandex.cloud.video.v1.Episode.VisibilityStatus\x12J\n\rpublic_access\x18\xe8\x07 \x01(\x0b\x32\x30.yandex.cloud.video.v1.EpisodePublicAccessRightsH\x00\x12S\n\x12\x61uth_system_access\x18\xea\x07 \x01(\x0b\x32\x34.yandex.cloud.video.v1.EpisodeAuthSystemAccessRightsH\x00\x12M\n\x0fsign_url_access\x18\xeb\x07 \x01(\x0b\x32\x31.yandex.cloud.video.v1.EpisodeSignURLAccessRightsH\x00\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"U\n\x10VisibilityStatus\x12!\n\x1dVISIBILITY_STATUS_UNSPECIFIED\x10\x00\x12\r\n\tPUBLISHED\x10\x01\x12\x0f\n\x0bUNPUBLISHED\x10\x02\x42\x0f\n\raccess_rightsJ\x06\x08\xe9\x07\x10\xea\x07J\x04\x08\x0b\x10\x64J\x05\x08\x66\x10\xe8\x07\"\x1b\n\x19\x45pisodePublicAccessRights\"\x1f\n\x1d\x45pisodeAuthSystemAccessRights\"\x1c\n\x1a\x45pisodeSignURLAccessRightsB\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.episode_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_EPISODE']._serialized_start=96
  _globals['_EPISODE']._serialized_end=866
  _globals['_EPISODE_VISIBILITYSTATUS']._serialized_start=743
  _globals['_EPISODE_VISIBILITYSTATUS']._serialized_end=828
  _globals['_EPISODEPUBLICACCESSRIGHTS']._serialized_start=868
  _globals['_EPISODEPUBLICACCESSRIGHTS']._serialized_end=895
  _globals['_EPISODEAUTHSYSTEMACCESSRIGHTS']._serialized_start=897
  _globals['_EPISODEAUTHSYSTEMACCESSRIGHTS']._serialized_end=928
  _globals['_EPISODESIGNURLACCESSRIGHTS']._serialized_start=930
  _globals['_EPISODESIGNURLACCESSRIGHTS']._serialized_end=958
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Manifest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ManifestType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ManifestTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Manifest._ManifestType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MANIFEST_TYPE_UNSPECIFIED: Manifest._ManifestType.ValueType  # 0
        DASH: Manifest._ManifestType.ValueType  # 1
        HLS: Manifest._ManifestType.ValueType  # 2

    class ManifestType(_ManifestType, metaclass=_ManifestTypeEnumTypeWrapper): ...
    MANIFEST_TYPE_UNSPECIFIED: Manifest.ManifestType.ValueType  # 0
    DASH: Manifest.ManifestType.ValueType  # 1
    HLS: Manifest.ManifestType.ValueType  # 2

    URL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    url: builtins.str
    type: global___Manifest.ManifestType.ValueType
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        type: global___Manifest.ManifestType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["type", b"type", "url", b"url"]) -> None: ...

global___Manifest = Manifest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/postgresql/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/mdb/postgresql/v1/user.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xa6\x03\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.Permission\x12\x12\n\nconn_limit\x18\x04 \x01(\x03\x12>\n\x08settings\x18\x05 \x01(\x0b\x32,.yandex.cloud.mdb.postgresql.v1.UserSettings\x12)\n\x05login\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x06grants\x18\x07 \x03(\tB\x19\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12\x37\n\x13\x64\x65letion_protection\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12X\n\x18user_password_encryption\x18\t \x01(\x0e\x32\x36.yandex.cloud.mdb.postgresql.v1.UserPasswordEncryption\"#\n\nPermission\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\"\xfe\x03\n\x08UserSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.Permission\x12\x39\n\nconn_limit\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04>=10\x12>\n\x08settings\x18\x05 \x01(\x0b\x32,.yandex.cloud.mdb.postgresql.v1.UserSettings\x12)\n\x05login\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x06grants\x18\x07 \x03(\tB\x19\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12\x37\n\x13\x64\x65letion_protection\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12X\n\x18user_password_encryption\x18\t \x01(\x0e\x32\x36.yandex.cloud.mdb.postgresql.v1.UserPasswordEncryption\"\x88\x03\n\x0fPGAuditSettings\x12O\n\x03log\x18\x01 \x03(\x0e\x32\x42.yandex.cloud.mdb.postgresql.v1.PGAuditSettings.PGAuditSettingsLog\"\xa3\x02\n\x12PGAuditSettingsLog\x12%\n!PG_AUDIT_SETTINGS_LOG_UNSPECIFIED\x10\x00\x12\x1e\n\x1aPG_AUDIT_SETTINGS_LOG_READ\x10\x01\x12\x1f\n\x1bPG_AUDIT_SETTINGS_LOG_WRITE\x10\x02\x12\"\n\x1ePG_AUDIT_SETTINGS_LOG_FUNCTION\x10\x03\x12\x1e\n\x1aPG_AUDIT_SETTINGS_LOG_ROLE\x10\x04\x12\x1d\n\x19PG_AUDIT_SETTINGS_LOG_DDL\x10\x05\x12\x1e\n\x1aPG_AUDIT_SETTINGS_LOG_MISC\x10\x06\x12\"\n\x1ePG_AUDIT_SETTINGS_LOG_MISC_SET\x10\x07\"\xcc\x0c\n\x0cUserSettings\x12h\n\x1d\x64\x65\x66\x61ult_transaction_isolation\x18\x01 \x01(\x0e\x32\x41.yandex.cloud.mdb.postgresql.v1.UserSettings.TransactionIsolation\x12\x31\n\x0clock_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1alog_min_duration_statement\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12Z\n\x12synchronous_commit\x18\x04 \x01(\x0e\x32>.yandex.cloud.mdb.postgresql.v1.UserSettings.SynchronousCommit\x12\x34\n\x0ftemp_file_limit\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12P\n\rlog_statement\x18\x06 \x01(\x0e\x32\x39.yandex.cloud.mdb.postgresql.v1.UserSettings.LogStatement\x12K\n\tpool_mode\x18\x07 \x01(\x0e\x32\x38.yandex.cloud.mdb.postgresql.v1.UserSettings.PoolingMode\x12?\n\x1bprepared_statements_pooling\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x0f\x63\x61tchup_timeout\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12wal_sender_timeout\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12Z\n#idle_in_transaction_session_timeout\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12\x36\n\x11statement_timeout\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x07pgaudit\x18\r \x01(\x0b\x32/.yandex.cloud.mdb.postgresql.v1.PGAuditSettings\"\xd6\x01\n\x11SynchronousCommit\x12\"\n\x1eSYNCHRONOUS_COMMIT_UNSPECIFIED\x10\x00\x12\x19\n\x15SYNCHRONOUS_COMMIT_ON\x10\x01\x12\x1a\n\x16SYNCHRONOUS_COMMIT_OFF\x10\x02\x12\x1c\n\x18SYNCHRONOUS_COMMIT_LOCAL\x10\x03\x12#\n\x1fSYNCHRONOUS_COMMIT_REMOTE_WRITE\x10\x04\x12#\n\x1fSYNCHRONOUS_COMMIT_REMOTE_APPLY\x10\x05\"\x8a\x01\n\x0cLogStatement\x12\x1d\n\x19LOG_STATEMENT_UNSPECIFIED\x10\x00\x12\x16\n\x12LOG_STATEMENT_NONE\x10\x01\x12\x15\n\x11LOG_STATEMENT_DDL\x10\x02\x12\x15\n\x11LOG_STATEMENT_MOD\x10\x03\x12\x15\n\x11LOG_STATEMENT_ALL\x10\x04\"\xe6\x01\n\x14TransactionIsolation\x12%\n!TRANSACTION_ISOLATION_UNSPECIFIED\x10\x00\x12*\n&TRANSACTION_ISOLATION_READ_UNCOMMITTED\x10\x01\x12(\n$TRANSACTION_ISOLATION_READ_COMMITTED\x10\x02\x12)\n%TRANSACTION_ISOLATION_REPEATABLE_READ\x10\x03\x12&\n\"TRANSACTION_ISOLATION_SERIALIZABLE\x10\x04\"X\n\x0bPoolingMode\x12\x1c\n\x18POOLING_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\x12\r\n\tSTATEMENT\x10\x03*\x90\x01\n\x16UserPasswordEncryption\x12(\n$USER_PASSWORD_ENCRYPTION_UNSPECIFIED\x10\x00\x12 \n\x1cUSER_PASSWORD_ENCRYPTION_MD5\x10\x01\x12*\n&USER_PASSWORD_ENCRYPTION_SCRAM_SHA_256\x10\x02\x42s\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _USER.fields_by_name['grants']._options = None
  _USER.fields_by_name['grants']._serialized_options = b'\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _USERSPEC.fields_by_name['name']._options = None
  _USERSPEC.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _USERSPEC.fields_by_name['password']._options = None
  _USERSPEC.fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _USERSPEC.fields_by_name['conn_limit']._options = None
  _USERSPEC.fields_by_name['conn_limit']._serialized_options = b'\372\3071\004>=10'
  _USERSPEC.fields_by_name['grants']._options = None
  _USERSPEC.fields_by_name['grants']._serialized_options = b'\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _USERSETTINGS.fields_by_name['idle_in_transaction_session_timeout']._options = None
  _USERSETTINGS.fields_by_name['idle_in_transaction_session_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_USERPASSWORDENCRYPTION']._serialized_start=3126
  _globals['_USERPASSWORDENCRYPTION']._serialized_end=3270
  _globals['_USER']._serialized_start=141
  _globals['_USER']._serialized_end=563
  _globals['_PERMISSION']._serialized_start=565
  _globals['_PERMISSION']._serialized_end=600
  _globals['_USERSPEC']._serialized_start=603
  _globals['_USERSPEC']._serialized_end=1113
  _globals['_PGAUDITSETTINGS']._serialized_start=1116
  _globals['_PGAUDITSETTINGS']._serialized_end=1508
  _globals['_PGAUDITSETTINGS_PGAUDITSETTINGSLOG']._serialized_start=1217
  _globals['_PGAUDITSETTINGS_PGAUDITSETTINGSLOG']._serialized_end=1508
  _globals['_USERSETTINGS']._serialized_start=1511
  _globals['_USERSETTINGS']._serialized_end=3123
  _globals['_USERSETTINGS_SYNCHRONOUSCOMMIT']._serialized_start=2445
  _globals['_USERSETTINGS_SYNCHRONOUSCOMMIT']._serialized_end=2659
  _globals['_USERSETTINGS_LOGSTATEMENT']._serialized_start=2662
  _globals['_USERSETTINGS_LOGSTATEMENT']._serialized_end=2800
  _globals['_USERSETTINGS_TRANSACTIONISOLATION']._serialized_start=2803
  _globals['_USERSETTINGS_TRANSACTIONISOLATION']._serialized_end=3033
  _globals['_USERSETTINGS_POOLINGMODE']._serialized_start=3035
  _globals['_USERSETTINGS_POOLINGMODE']._serialized_end=3123
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _IpVersion:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IpVersionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IpVersion.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    IP_VERSION_UNSPECIFIED: _IpVersion.ValueType  # 0
    IPV4: _IpVersion.ValueType  # 1
    IPV6: _IpVersion.ValueType  # 2

class IpVersion(_IpVersion, metaclass=_IpVersionEnumTypeWrapper): ...

IP_VERSION_UNSPECIFIED: IpVersion.ValueType  # 0
IPV4: IpVersion.ValueType  # 1
IPV6: IpVersion.ValueType  # 2
global___IpVersion = IpVersion

@typing.final
class Subnet(google.protobuf.message.Message):
    """A Subnet resource. For more information, see [Subnets](/docs/vpc/concepts/network#subnet)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    V4_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    V6_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_ID_FIELD_NUMBER: builtins.int
    DHCP_OPTIONS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the subnet."""
    folder_id: builtins.str
    """ID of the folder that the subnet belongs to."""
    name: builtins.str
    """Name of the subnet. 
    The name must be unique within the folder. 
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the subnet. 0-256 characters long."""
    network_id: builtins.str
    """ID of the network the subnet belongs to."""
    zone_id: builtins.str
    """ID of the availability zone where the subnet resides.
    if subnet will be zonal
    """
    route_table_id: builtins.str
    """ID of route table the subnet is linked to."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs. 
        No more than 64 per resource. 
        The maximum string length in characters for each value is 63. 
        Each value must match the regular expression `[-_0-9a-z]*`. 
        The string length in characters for each key must be 1-63. 
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    @property
    def v4_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """CIDR block.
        The range of internal addresses that are defined for this subnet.
        This field can be set only at Subnet resource creation time and cannot be changed.
        For example, 10.0.0.0/22 or 192.168.0.0/24.
        Minimum subnet size is /28, maximum subnet size is /16.
        """

    @property
    def v6_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IPv6 not available yet."""

    @property
    def dhcp_options(self) -> global___DhcpOptions:
        """DHCP options for the subnet."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        v4_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
        v6_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
        route_table_id: builtins.str = ...,
        dhcp_options: global___DhcpOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "dhcp_options", b"dhcp_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "dhcp_options", b"dhcp_options", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "network_id", b"network_id", "route_table_id", b"route_table_id", "v4_cidr_blocks", b"v4_cidr_blocks", "v6_cidr_blocks", b"v6_cidr_blocks", "zone_id", b"zone_id"]) -> None: ...

global___Subnet = Subnet

@typing.final
class DhcpOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_NAME_SERVERS_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    NTP_SERVERS_FIELD_NUMBER: builtins.int
    domain_name: builtins.str
    """A domain name to us as a suffix when resolving host names in this subnet."""
    @property
    def domain_name_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of DHCP servers for this subnet."""

    @property
    def ntp_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of NTP servers for this subnet."""

    def __init__(
        self,
        *,
        domain_name_servers: collections.abc.Iterable[builtins.str] | None = ...,
        domain_name: builtins.str = ...,
        ntp_servers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain_name", b"domain_name", "domain_name_servers", b"domain_name_servers", "ntp_servers", b"ntp_servers"]) -> None: ...

global___DhcpOptions = DhcpOptions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tuning/v1/tuning_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.ai.tuning.v1 import tuning_task_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__task__pb2
from yandex.cloud.ai.tuning.v1 import tuning_types_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__types__pb2
from yandex.cloud.ai.tuning.v1 import tuning_optimizers_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__optimizers__pb2
from yandex.cloud.ai.tuning.v1 import tuning_schedulers_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__schedulers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/ai/tuning/v1/tuning_service.proto\x12\x19yandex.cloud.ai.tuning.v1\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a+yandex/cloud/ai/tuning/v1/tuning_task.proto\x1a,yandex/cloud/ai/tuning/v1/tuning_types.proto\x1a\x31yandex/cloud/ai/tuning/v1/tuning_optimizers.proto\x1a\x31yandex/cloud/ai/tuning/v1/tuning_schedulers.proto\"T\n\x12ListTuningsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"k\n\x13ListTuningsResponse\x12;\n\x0ctuning_tasks\x18\x01 \x03(\x0b\x32%.yandex.cloud.ai.tuning.v1.TuningTask\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x15\x44\x65scribeTuningRequest\x12\x1c\n\x0etuning_task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"T\n\x16\x44\x65scribeTuningResponse\x12:\n\x0btuning_task\x18\x01 \x01(\x0b\x32%.yandex.cloud.ai.tuning.v1.TuningTask\"3\n\x13\x43\x61ncelTuningRequest\x12\x1c\n\x0etuning_task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\".\n\x14\x43\x61ncelTuningResponse\x12\x16\n\x0etuning_task_id\x18\x01 \x01(\t\"\x8c\x01\n\x0eTuningResponse\x12\x16\n\x0etuning_task_id\x18\x03 \x01(\t\x12<\n\x06status\x18\x04 \x01(\x0e\x32,.yandex.cloud.ai.tuning.v1.TuningTask.Status\x12\x18\n\x10target_model_uri\x18\x05 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"f\n\x0eTuningMetadata\x12\x16\n\x0etuning_task_id\x18\x01 \x01(\t\x12<\n\x06status\x18\x02 \x01(\x0e\x32,.yandex.cloud.ai.tuning.v1.TuningTask.Status\"\x86\x06\n\rTuningRequest\x12\x1c\n\x0e\x62\x61se_model_uri\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12X\n\x0etrain_datasets\x18\x02 \x03(\x0b\x32\x38.yandex.cloud.ai.tuning.v1.TuningRequest.WeightedDatasetB\x06\x82\xc8\x31\x02>0\x12U\n\x13validation_datasets\x18\x03 \x03(\x0b\x32\x38.yandex.cloud.ai.tuning.v1.TuningRequest.WeightedDataset\x12^\n\x17text_to_text_completion\x18\x64 \x01(\x0b\x32;.yandex.cloud.ai.tuning.v1.TextToTextCompletionTuningParamsH\x00\x12g\n\x1etext_classification_multilabel\x18\x65 \x01(\x0b\x32=.yandex.cloud.ai.tuning.v1.TextClassificationMultilabelParamsH\x00\x12g\n\x1etext_classification_multiclass\x18\x66 \x01(\x0b\x32=.yandex.cloud.ai.tuning.v1.TextClassificationMulticlassParamsH\x00\x12\r\n\x04name\x18\xc8\x01 \x01(\t\x12\x14\n\x0b\x64\x65scription\x18\xc9\x01 \x01(\t\x12\x45\n\x06labels\x18\xca\x01 \x03(\x0b\x32\x34.yandex.cloud.ai.tuning.v1.TuningRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a;\n\x0fWeightedDataset\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x42\x0f\n\rtuning_paramsJ\x04\x08\x04\x10\x64J\x05\x08g\x10\xc8\x01\"\x89\x06\n TextToTextCompletionTuningParams\x12\x0c\n\x04seed\x18\x01 \x01(\x03\x12\n\n\x02lr\x18\x02 \x01(\x01\x12\x11\n\tn_samples\x18\x03 \x01(\x03\x12\x1c\n\x14\x61\x64\x64itional_arguments\x18\x07 \x01(\t\x12\x39\n\x04lora\x18\x64 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.TuningTypeLoraH\x00\x12\x46\n\x0bprompt_tune\x18\x65 \x01(\x0b\x32/.yandex.cloud.ai.tuning.v1.TuningTypePromptTuneH\x00\x12Y\n\tscheduler\x18\xc8\x01 \x01(\x0b\x32\x45.yandex.cloud.ai.tuning.v1.TextToTextCompletionTuningParams.Scheduler\x12Y\n\toptimizer\x18\xc9\x01 \x01(\x0b\x32\x45.yandex.cloud.ai.tuning.v1.TextToTextCompletionTuningParams.Optimizer\x1a\xed\x01\n\tScheduler\x12<\n\x06linear\x18\x01 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerLinearH\x00\x12@\n\x08\x63onstant\x18\x02 \x01(\x0b\x32,.yandex.cloud.ai.tuning.v1.SchedulerConstantH\x00\x12<\n\x06\x63osine\x18\x03 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerCosineH\x00\x12\x14\n\x0cwarmup_ratio\x18\x65 \x01(\x01\x42\x06\n\x04typeJ\x04\x08\x04\x10\x65\x1aO\n\tOptimizer\x12:\n\x05\x61\x64\x61mw\x18\x01 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.OptimizerAdamwH\x00\x42\x06\n\x04typeB\r\n\x0btuning_typeJ\x04\x08\x04\x10\x07J\x04\x08\x08\x10\x64J\x05\x08\x66\x10\xc8\x01\"\x8f\x06\n\"TextClassificationMultilabelParams\x12\x0c\n\x04seed\x18\x01 \x01(\x03\x12\n\n\x02lr\x18\x02 \x01(\x01\x12\x11\n\tn_samples\x18\x03 \x01(\x03\x12\x1c\n\x14\x61\x64\x64itional_arguments\x18\x07 \x01(\t\x12\x39\n\x04lora\x18\x64 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.TuningTypeLoraH\x00\x12\x46\n\x0bprompt_tune\x18\x65 \x01(\x0b\x32/.yandex.cloud.ai.tuning.v1.TuningTypePromptTuneH\x00\x12[\n\tscheduler\x18\xc8\x01 \x01(\x0b\x32G.yandex.cloud.ai.tuning.v1.TextClassificationMultilabelParams.Scheduler\x12[\n\toptimizer\x18\xc9\x01 \x01(\x0b\x32G.yandex.cloud.ai.tuning.v1.TextClassificationMultilabelParams.Optimizer\x1a\xed\x01\n\tScheduler\x12<\n\x06linear\x18\x01 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerLinearH\x00\x12@\n\x08\x63onstant\x18\x02 \x01(\x0b\x32,.yandex.cloud.ai.tuning.v1.SchedulerConstantH\x00\x12<\n\x06\x63osine\x18\x03 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerCosineH\x00\x12\x14\n\x0cwarmup_ratio\x18\x65 \x01(\x01\x42\x06\n\x04typeJ\x04\x08\x04\x10\x65\x1aO\n\tOptimizer\x12:\n\x05\x61\x64\x61mw\x18\x01 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.OptimizerAdamwH\x00\x42\x06\n\x04typeB\r\n\x0btuning_typeJ\x04\x08\x04\x10\x07J\x04\x08\x08\x10\x64J\x05\x08\x66\x10\xc8\x01\"\x8f\x06\n\"TextClassificationMulticlassParams\x12\x0c\n\x04seed\x18\x01 \x01(\x03\x12\n\n\x02lr\x18\x02 \x01(\x01\x12\x11\n\tn_samples\x18\x03 \x01(\x03\x12\x1c\n\x14\x61\x64\x64itional_arguments\x18\x07 \x01(\t\x12\x39\n\x04lora\x18\x64 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.TuningTypeLoraH\x00\x12\x46\n\x0bprompt_tune\x18\x65 \x01(\x0b\x32/.yandex.cloud.ai.tuning.v1.TuningTypePromptTuneH\x00\x12[\n\tscheduler\x18\xc8\x01 \x01(\x0b\x32G.yandex.cloud.ai.tuning.v1.TextClassificationMulticlassParams.Scheduler\x12[\n\toptimizer\x18\xc9\x01 \x01(\x0b\x32G.yandex.cloud.ai.tuning.v1.TextClassificationMulticlassParams.Optimizer\x1a\xed\x01\n\tScheduler\x12<\n\x06linear\x18\x01 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerLinearH\x00\x12@\n\x08\x63onstant\x18\x02 \x01(\x0b\x32,.yandex.cloud.ai.tuning.v1.SchedulerConstantH\x00\x12<\n\x06\x63osine\x18\x03 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerCosineH\x00\x12\x14\n\x0cwarmup_ratio\x18\x65 \x01(\x01\x42\x06\n\x04typeJ\x04\x08\x04\x10\x65\x1aO\n\tOptimizer\x12:\n\x05\x61\x64\x61mw\x18\x01 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.OptimizerAdamwH\x00\x42\x06\n\x04typeB\r\n\x0btuning_typeJ\x04\x08\x04\x10\x07J\x04\x08\x08\x10\x64J\x05\x08\x66\x10\xc8\x01\"-\n\x14GetMetricsUrlRequest\x12\x15\n\x07task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\")\n\x15GetMetricsUrlResponse\x12\x10\n\x08load_url\x18\x01 \x01(\t\"*\n\x11GetOptionsRequest\x12\x15\n\x07task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xdd\x02\n\x12GetOptionsResponse\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x61se_model_uri\x18\x02 \x01(\t\x12P\n\x0etrain_datasets\x18\x03 \x03(\x0b\x32\x38.yandex.cloud.ai.tuning.v1.TuningRequest.WeightedDataset\x12U\n\x13validation_datasets\x18\x04 \x03(\x0b\x32\x38.yandex.cloud.ai.tuning.v1.TuningRequest.WeightedDataset\x12^\n\x17text_to_text_completion\x18\x64 \x01(\x0b\x32;.yandex.cloud.ai.tuning.v1.TextToTextCompletionTuningParamsH\x00\x42\x0f\n\rtuning_paramsJ\x04\x08\x05\x10\x64\x32\xac\x05\n\rTuningService\x12y\n\x04Tune\x12(.yandex.cloud.ai.tuning.v1.TuningRequest\x1a!.yandex.cloud.operation.Operation\"$\xb2\xd2* \n\x0eTuningMetadata\x12\x0eTuningResponse\x12\x65\n\x04List\x12-.yandex.cloud.ai.tuning.v1.ListTuningsRequest\x1a..yandex.cloud.ai.tuning.v1.ListTuningsResponse\x12o\n\x08\x44\x65scribe\x12\x30.yandex.cloud.ai.tuning.v1.DescribeTuningRequest\x1a\x31.yandex.cloud.ai.tuning.v1.DescribeTuningResponse\x12i\n\x06\x43\x61ncel\x12..yandex.cloud.ai.tuning.v1.CancelTuningRequest\x1a/.yandex.cloud.ai.tuning.v1.CancelTuningResponse\x12r\n\rGetMetricsUrl\x12/.yandex.cloud.ai.tuning.v1.GetMetricsUrlRequest\x1a\x30.yandex.cloud.ai.tuning.v1.GetMetricsUrlResponse\x12i\n\nGetOptions\x12,.yandex.cloud.ai.tuning.v1.GetOptionsRequest\x1a-.yandex.cloud.ai.tuning.v1.GetOptionsResponseBc\n\x1dyandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tuning.v1.tuning_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomo'
  _LISTTUNINGSREQUEST.fields_by_name['folder_id']._options = None
  _LISTTUNINGSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _DESCRIBETUNINGREQUEST.fields_by_name['tuning_task_id']._options = None
  _DESCRIBETUNINGREQUEST.fields_by_name['tuning_task_id']._serialized_options = b'\350\3071\001'
  _CANCELTUNINGREQUEST.fields_by_name['tuning_task_id']._options = None
  _CANCELTUNINGREQUEST.fields_by_name['tuning_task_id']._serialized_options = b'\350\3071\001'
  _TUNINGREQUEST_LABELSENTRY._options = None
  _TUNINGREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _TUNINGREQUEST_WEIGHTEDDATASET.fields_by_name['dataset_id']._options = None
  _TUNINGREQUEST_WEIGHTEDDATASET.fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _TUNINGREQUEST.fields_by_name['base_model_uri']._options = None
  _TUNINGREQUEST.fields_by_name['base_model_uri']._serialized_options = b'\350\3071\001'
  _TUNINGREQUEST.fields_by_name['train_datasets']._options = None
  _TUNINGREQUEST.fields_by_name['train_datasets']._serialized_options = b'\202\3101\002>0'
  _GETMETRICSURLREQUEST.fields_by_name['task_id']._options = None
  _GETMETRICSURLREQUEST.fields_by_name['task_id']._serialized_options = b'\350\3071\001'
  _GETOPTIONSREQUEST.fields_by_name['task_id']._options = None
  _GETOPTIONSREQUEST.fields_by_name['task_id']._serialized_options = b'\350\3071\001'
  _TUNINGSERVICE.methods_by_name['Tune']._options = None
  _TUNINGSERVICE.methods_by_name['Tune']._serialized_options = b'\262\322* \n\016TuningMetadata\022\016TuningResponse'
  _globals['_LISTTUNINGSREQUEST']._serialized_start=375
  _globals['_LISTTUNINGSREQUEST']._serialized_end=459
  _globals['_LISTTUNINGSRESPONSE']._serialized_start=461
  _globals['_LISTTUNINGSRESPONSE']._serialized_end=568
  _globals['_DESCRIBETUNINGREQUEST']._serialized_start=570
  _globals['_DESCRIBETUNINGREQUEST']._serialized_end=623
  _globals['_DESCRIBETUNINGRESPONSE']._serialized_start=625
  _globals['_DESCRIBETUNINGRESPONSE']._serialized_end=709
  _globals['_CANCELTUNINGREQUEST']._serialized_start=711
  _globals['_CANCELTUNINGREQUEST']._serialized_end=762
  _globals['_CANCELTUNINGRESPONSE']._serialized_start=764
  _globals['_CANCELTUNINGRESPONSE']._serialized_end=810
  _globals['_TUNINGRESPONSE']._serialized_start=813
  _globals['_TUNINGRESPONSE']._serialized_end=953
  _globals['_TUNINGMETADATA']._serialized_start=955
  _globals['_TUNINGMETADATA']._serialized_end=1057
  _globals['_TUNINGREQUEST']._serialized_start=1060
  _globals['_TUNINGREQUEST']._serialized_end=1834
  _globals['_TUNINGREQUEST_LABELSENTRY']._serialized_start=1698
  _globals['_TUNINGREQUEST_LABELSENTRY']._serialized_end=1743
  _globals['_TUNINGREQUEST_WEIGHTEDDATASET']._serialized_start=1745
  _globals['_TUNINGREQUEST_WEIGHTEDDATASET']._serialized_end=1804
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS']._serialized_start=1837
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS']._serialized_end=2614
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS_SCHEDULER']._serialized_start=2262
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS_SCHEDULER']._serialized_end=2499
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS_OPTIMIZER']._serialized_start=2501
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS_OPTIMIZER']._serialized_end=2580
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS']._serialized_start=2617
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS']._serialized_end=3400
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS_SCHEDULER']._serialized_start=2262
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS_SCHEDULER']._serialized_end=2499
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS_OPTIMIZER']._serialized_start=2501
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS_OPTIMIZER']._serialized_end=2580
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS']._serialized_start=3403
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS']._serialized_end=4186
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS_SCHEDULER']._serialized_start=2262
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS_SCHEDULER']._serialized_end=2499
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS_OPTIMIZER']._serialized_start=2501
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS_OPTIMIZER']._serialized_end=2580
  _globals['_GETMETRICSURLREQUEST']._serialized_start=4188
  _globals['_GETMETRICSURLREQUEST']._serialized_end=4233
  _globals['_GETMETRICSURLRESPONSE']._serialized_start=4235
  _globals['_GETMETRICSURLRESPONSE']._serialized_end=4276
  _globals['_GETOPTIONSREQUEST']._serialized_start=4278
  _globals['_GETOPTIONSREQUEST']._serialized_end=4320
  _globals['_GETOPTIONSRESPONSE']._serialized_start=4323
  _globals['_GETOPTIONSRESPONSE']._serialized_end=4672
  _globals['_TUNINGSERVICE']._serialized_start=4675
  _globals['_TUNINGSERVICE']._serialized_end=5359
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.cic.v1.peering_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PrivateConnection(google.protobuf.message.Message):
    """A PrivateConnection resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class StaticRoute(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PREFIX_FIELD_NUMBER: builtins.int
        NEXT_HOP_FIELD_NUMBER: builtins.int
        prefix: builtins.str
        """Prefix.
        It's an ip with format ipPrefix/length where address part of ipPrefix is 0.
        """
        @property
        def next_hop(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """PeerIp.
            It's an ip with just an ipAddress format without mask.
            Will be removed in some next release
            """

        def __init__(
            self,
            *,
            prefix: builtins.str = ...,
            next_hop: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["next_hop", b"next_hop", "prefix", b"prefix"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    VLAN_ID_FIELD_NUMBER: builtins.int
    IPV4_PEERING_FIELD_NUMBER: builtins.int
    IPV4_STATIC_ROUTES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the privateConnection."""
    name: builtins.str
    """Name of the privateConnection.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the privateConnection. 0-256 characters long."""
    folder_id: builtins.str
    """ID of the folder that the privateConnection belongs to."""
    region_id: builtins.str
    """ID of the region that the privateConnection belongs to."""
    trunk_connection_id: builtins.str
    """ID of the trunk_connection that the privateConnection belongs to."""
    @property
    def vlan_id(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """VLAN_ID that the privateConnection uses in multiplexing.
        Not used in connections over partners-II
        Value range: [1, 4095]
        """

    @property
    def ipv4_peering(self) -> yandex.cloud.cic.v1.peering_pb2.Peering:
        """IPv4 peering config of connection"""

    @property
    def ipv4_static_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateConnection.StaticRoute]:
        """IPv4 StaticRoute config of connection"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        region_id: builtins.str = ...,
        trunk_connection_id: builtins.str = ...,
        vlan_id: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ipv4_peering: yandex.cloud.cic.v1.peering_pb2.Peering | None = ...,
        ipv4_static_routes: collections.abc.Iterable[global___PrivateConnection.StaticRoute] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ipv4_peering", b"ipv4_peering", "vlan_id", b"vlan_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "id", b"id", "ipv4_peering", b"ipv4_peering", "ipv4_static_routes", b"ipv4_static_routes", "labels", b"labels", "name", b"name", "region_id", b"region_id", "trunk_connection_id", b"trunk_connection_id", "vlan_id", b"vlan_id"]) -> None: ...

global___PrivateConnection = PrivateConnection



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cloudrouter/v1/routing_instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.cloudrouter.v1 import routing_instance_pb2 as yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/cloudrouter/v1/routing_instance_service.proto\x12\x1byandex.cloud.cloudrouter.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x32yandex/cloud/cloudrouter/v1/routing_instance.proto\"F\n\x19GetRoutingInstanceRequest\x12)\n\x13routing_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"d\n1GetRoutingInstanceByCicPrivateConnectionIdRequest\x12/\n\x19\x63ic_private_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"O\n\'GetRoutingInstanceByVpcNetworkIdRequest\x12$\n\x0evpc_network_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x98\x01\n\x1bListRoutingInstancesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x80\x01\n\x1cListRoutingInstancesResponse\x12G\n\x11routing_instances\x18\x01 \x03(\x0b\x32,.yandex.cloud.cloudrouter.v1.RoutingInstance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xfd\x04\n\x16RoutingInstanceService\x12\x9e\x01\n\x03Get\x12\x36.yandex.cloud.cloudrouter.v1.GetRoutingInstanceRequest\x1a,.yandex.cloud.cloudrouter.v1.RoutingInstance\"1\x82\xd3\xe4\x93\x02+\x12)/vpc/v1/cloudrouter/{routing_instance_id}\x12\x87\x01\n\x11GetByVpcNetworkId\x12\x44.yandex.cloud.cloudrouter.v1.GetRoutingInstanceByVpcNetworkIdRequest\x1a,.yandex.cloud.cloudrouter.v1.RoutingInstance\x12\x9b\x01\n\x1bGetByCicPrivateConnectionId\x12N.yandex.cloud.cloudrouter.v1.GetRoutingInstanceByCicPrivateConnectionIdRequest\x1a,.yandex.cloud.cloudrouter.v1.RoutingInstance\x12\x99\x01\n\x04List\x12\x38.yandex.cloud.cloudrouter.v1.ListRoutingInstancesRequest\x1a\x39.yandex.cloud.cloudrouter.v1.ListRoutingInstancesResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/vpc/v1/cloudroutersBn\n\x1fyandex.cloud.api.cloudrouter.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudrouter/v1;cloudrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudrouter.v1.routing_instance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.cloudrouter.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudrouter/v1;cloudrouter'
  _GETROUTINGINSTANCEREQUEST.fields_by_name['routing_instance_id']._options = None
  _GETROUTINGINSTANCEREQUEST.fields_by_name['routing_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST.fields_by_name['cic_private_connection_id']._options = None
  _GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST.fields_by_name['cic_private_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST.fields_by_name['vpc_network_id']._options = None
  _GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST.fields_by_name['vpc_network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['folder_id']._options = None
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['page_size']._options = None
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['page_token']._options = None
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['filter']._options = None
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _ROUTINGINSTANCESERVICE.methods_by_name['Get']._options = None
  _ROUTINGINSTANCESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/vpc/v1/cloudrouter/{routing_instance_id}'
  _ROUTINGINSTANCESERVICE.methods_by_name['List']._options = None
  _ROUTINGINSTANCESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\026\022\024/vpc/v1/cloudrouters'
  _globals['_GETROUTINGINSTANCEREQUEST']._serialized_start=204
  _globals['_GETROUTINGINSTANCEREQUEST']._serialized_end=274
  _globals['_GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST']._serialized_start=276
  _globals['_GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST']._serialized_end=376
  _globals['_GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST']._serialized_start=378
  _globals['_GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST']._serialized_end=457
  _globals['_LISTROUTINGINSTANCESREQUEST']._serialized_start=460
  _globals['_LISTROUTINGINSTANCESREQUEST']._serialized_end=612
  _globals['_LISTROUTINGINSTANCESRESPONSE']._serialized_start=615
  _globals['_LISTROUTINGINSTANCESRESPONSE']._serialized_end=743
  _globals['_ROUTINGINSTANCESERVICE']._serialized_start=746
  _globals['_ROUTINGINSTANCESERVICE']._serialized_end=1383
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/subtitle_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import subtitle_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_subtitle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/video/v1/subtitle_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a$yandex/cloud/video/v1/subtitle.proto\"7\n\x12GetSubtitleRequest\x12!\n\x0bsubtitle_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x93\x01\n\x14ListSubtitlesRequest\x12\x1d\n\tpage_size\x18\x64 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x65 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x1d\n\x08video_id\x18\xe8\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x42\x11\n\tparent_id\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x64J\x05\x08\x66\x10\xe8\x07\"j\n\x15ListSubtitlesResponse\x12\x32\n\tsubtitles\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.video.v1.Subtitle\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xc9\x01\n\x15\x43reateSubtitleRequest\x12\x10\n\x08language\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x1d\n\x08video_id\x18\xe8\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12>\n\x06upload\x18\xcc\x08 \x01(\x0b\x32+.yandex.cloud.video.v1.SubtitleUploadParamsH\x01\x42\x11\n\tparent_id\x12\x04\xc0\xc1\x31\x01\x42\x0e\n\x06source\x12\x04\xc0\xc1\x31\x01J\x05\x08\x03\x10\xe8\x07J\x06\x08\xe9\x07\x10\xcc\x08\".\n\x14SubtitleUploadParams\x12\x16\n\x08\x66ilename\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"-\n\x16\x43reateSubtitleMetadata\x12\x13\n\x0bsubtitle_id\x18\x01 \x01(\t\"E\n GenerateSubtitleUploadURLRequest\x12!\n\x0bsubtitle_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n!GenerateSubtitleUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\":\n\x15\x44\x65leteSubtitleRequest\x12!\n\x0bsubtitle_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteSubtitleMetadata\x12\x13\n\x0bsubtitle_id\x18\x01 \x01(\t2\xb1\x06\n\x0fSubtitleService\x12|\n\x03Get\x12).yandex.cloud.video.v1.GetSubtitleRequest\x1a\x1f.yandex.cloud.video.v1.Subtitle\")\x82\xd3\xe4\x93\x02#\x12!/video/v1/subtitles/{subtitle_id}\x12~\n\x04List\x12+.yandex.cloud.video.v1.ListSubtitlesRequest\x1a,.yandex.cloud.video.v1.ListSubtitlesResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/video/v1/subtitles\x12\x9f\x01\n\x06\x43reate\x12,.yandex.cloud.video.v1.CreateSubtitleRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2*\"\n\x16\x43reateSubtitleMetadata\x12\x08Subtitle\x82\xd3\xe4\x93\x02\x18\"\x13/video/v1/subtitles:\x01*\x12\xc3\x01\n\x11GenerateUploadURL\x12\x37.yandex.cloud.video.v1.GenerateSubtitleUploadURLRequest\x1a\x38.yandex.cloud.video.v1.GenerateSubtitleUploadURLResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/video/v1/subtitles/{subtitle_id}:generateUploadURL\x12\xb7\x01\n\x06\x44\x65lete\x12,.yandex.cloud.video.v1.DeleteSubtitleRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*/\n\x16\x44\x65leteSubtitleMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02#*!/video/v1/subtitles/{subtitle_id}B\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.subtitle_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _GETSUBTITLEREQUEST.fields_by_name['subtitle_id']._options = None
  _GETSUBTITLEREQUEST.fields_by_name['subtitle_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSUBTITLESREQUEST.oneofs_by_name['parent_id']._options = None
  _LISTSUBTITLESREQUEST.oneofs_by_name['parent_id']._serialized_options = b'\300\3011\001'
  _LISTSUBTITLESREQUEST.fields_by_name['page_size']._options = None
  _LISTSUBTITLESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSUBTITLESREQUEST.fields_by_name['page_token']._options = None
  _LISTSUBTITLESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=200'
  _LISTSUBTITLESREQUEST.fields_by_name['video_id']._options = None
  _LISTSUBTITLESREQUEST.fields_by_name['video_id']._serialized_options = b'\212\3101\004<=50'
  _CREATESUBTITLEREQUEST.oneofs_by_name['parent_id']._options = None
  _CREATESUBTITLEREQUEST.oneofs_by_name['parent_id']._serialized_options = b'\300\3011\001'
  _CREATESUBTITLEREQUEST.oneofs_by_name['source']._options = None
  _CREATESUBTITLEREQUEST.oneofs_by_name['source']._serialized_options = b'\300\3011\001'
  _CREATESUBTITLEREQUEST.fields_by_name['video_id']._options = None
  _CREATESUBTITLEREQUEST.fields_by_name['video_id']._serialized_options = b'\212\3101\004<=50'
  _SUBTITLEUPLOADPARAMS.fields_by_name['filename']._options = None
  _SUBTITLEUPLOADPARAMS.fields_by_name['filename']._serialized_options = b'\350\3071\001'
  _GENERATESUBTITLEUPLOADURLREQUEST.fields_by_name['subtitle_id']._options = None
  _GENERATESUBTITLEUPLOADURLREQUEST.fields_by_name['subtitle_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETESUBTITLEREQUEST.fields_by_name['subtitle_id']._options = None
  _DELETESUBTITLEREQUEST.fields_by_name['subtitle_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _SUBTITLESERVICE.methods_by_name['Get']._options = None
  _SUBTITLESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002#\022!/video/v1/subtitles/{subtitle_id}'
  _SUBTITLESERVICE.methods_by_name['List']._options = None
  _SUBTITLESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/video/v1/subtitles'
  _SUBTITLESERVICE.methods_by_name['Create']._options = None
  _SUBTITLESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateSubtitleMetadata\022\010Subtitle\202\323\344\223\002\030\"\023/video/v1/subtitles:\001*'
  _SUBTITLESERVICE.methods_by_name['GenerateUploadURL']._options = None
  _SUBTITLESERVICE.methods_by_name['GenerateUploadURL']._serialized_options = b'\202\323\344\223\0025\0223/video/v1/subtitles/{subtitle_id}:generateUploadURL'
  _SUBTITLESERVICE.methods_by_name['Delete']._options = None
  _SUBTITLESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteSubtitleMetadata\022\025google.protobuf.Empty\202\323\344\223\002#*!/video/v1/subtitles/{subtitle_id}'
  _globals['_GETSUBTITLEREQUEST']._serialized_start=244
  _globals['_GETSUBTITLEREQUEST']._serialized_end=299
  _globals['_LISTSUBTITLESREQUEST']._serialized_start=302
  _globals['_LISTSUBTITLESREQUEST']._serialized_end=449
  _globals['_LISTSUBTITLESRESPONSE']._serialized_start=451
  _globals['_LISTSUBTITLESRESPONSE']._serialized_end=557
  _globals['_CREATESUBTITLEREQUEST']._serialized_start=560
  _globals['_CREATESUBTITLEREQUEST']._serialized_end=761
  _globals['_SUBTITLEUPLOADPARAMS']._serialized_start=763
  _globals['_SUBTITLEUPLOADPARAMS']._serialized_end=809
  _globals['_CREATESUBTITLEMETADATA']._serialized_start=811
  _globals['_CREATESUBTITLEMETADATA']._serialized_end=856
  _globals['_GENERATESUBTITLEUPLOADURLREQUEST']._serialized_start=858
  _globals['_GENERATESUBTITLEUPLOADURLREQUEST']._serialized_end=927
  _globals['_GENERATESUBTITLEUPLOADURLRESPONSE']._serialized_start=929
  _globals['_GENERATESUBTITLEUPLOADURLRESPONSE']._serialized_end=984
  _globals['_DELETESUBTITLEREQUEST']._serialized_start=986
  _globals['_DELETESUBTITLEREQUEST']._serialized_end=1044
  _globals['_DELETESUBTITLEMETADATA']._serialized_start=1046
  _globals['_DELETESUBTITLEMETADATA']._serialized_end=1091
  _globals['_SUBTITLESERVICE']._serialized_start=1094
  _globals['_SUBTITLESERVICE']._serialized_end=1911
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tuning/v1/tuning_task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/ai/tuning/v1/tuning_task.proto\x12\x19yandex.cloud.ai.tuning.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcb\x03\n\nTuningTask\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x14\n\x0coperation_id\x18\x03 \x01(\t\x12<\n\x06status\x18\x04 \x01(\x0e\x32,.yandex.cloud.ai.tuning.v1.TuningTask.Status\x12\x11\n\tfolder_id\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10source_model_uri\x18\n \x01(\t\x12\x18\n\x10target_model_uri\x18\x0b \x01(\t\"f\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05J\x04\x08\x02\x10\x03\x42\x63\n\x1dyandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tuning.v1.tuning_task_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomo'
  _globals['_TUNINGTASK']._serialized_start=108
  _globals['_TUNINGTASK']._serialized_end=567
  _globals['_TUNINGTASK_STATUS']._serialized_start=459
  _globals['_TUNINGTASK_STATUS']._serialized_end=561
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.datatransfer.v1.endpoint.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Parser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JSON_PARSER_FIELD_NUMBER: builtins.int
    AUDIT_TRAILS_V1_PARSER_FIELD_NUMBER: builtins.int
    CLOUD_LOGGING_PARSER_FIELD_NUMBER: builtins.int
    TSKV_PARSER_FIELD_NUMBER: builtins.int
    @property
    def json_parser(self) -> global___GenericParserCommon: ...
    @property
    def audit_trails_v1_parser(self) -> global___AuditTrailsV1Parser: ...
    @property
    def cloud_logging_parser(self) -> global___CloudLoggingParser: ...
    @property
    def tskv_parser(self) -> global___GenericParserCommon: ...
    def __init__(
        self,
        *,
        json_parser: global___GenericParserCommon | None = ...,
        audit_trails_v1_parser: global___AuditTrailsV1Parser | None = ...,
        cloud_logging_parser: global___CloudLoggingParser | None = ...,
        tskv_parser: global___GenericParserCommon | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audit_trails_v1_parser", b"audit_trails_v1_parser", "cloud_logging_parser", b"cloud_logging_parser", "json_parser", b"json_parser", "parser", b"parser", "tskv_parser", b"tskv_parser"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audit_trails_v1_parser", b"audit_trails_v1_parser", "cloud_logging_parser", b"cloud_logging_parser", "json_parser", b"json_parser", "parser", b"parser", "tskv_parser", b"tskv_parser"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["parser", b"parser"]) -> typing.Literal["json_parser", "audit_trails_v1_parser", "cloud_logging_parser", "tskv_parser"] | None: ...

global___Parser = Parser

@typing.final
class GenericParserCommon(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SCHEMA_FIELD_NUMBER: builtins.int
    NULL_KEYS_ALLOWED_FIELD_NUMBER: builtins.int
    ADD_REST_COLUMN_FIELD_NUMBER: builtins.int
    UNESCAPE_STRING_VALUES_FIELD_NUMBER: builtins.int
    null_keys_allowed: builtins.bool
    """Allow null keys, if no - null keys will be putted to unparsed data"""
    add_rest_column: builtins.bool
    """Will add _rest column for all unknown fields"""
    unescape_string_values: builtins.bool
    """Unescape string values"""
    @property
    def data_schema(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.DataSchema: ...
    def __init__(
        self,
        *,
        data_schema: yandex.cloud.datatransfer.v1.endpoint.common_pb2.DataSchema | None = ...,
        null_keys_allowed: builtins.bool = ...,
        add_rest_column: builtins.bool = ...,
        unescape_string_values: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_schema", b"data_schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["add_rest_column", b"add_rest_column", "data_schema", b"data_schema", "null_keys_allowed", b"null_keys_allowed", "unescape_string_values", b"unescape_string_values"]) -> None: ...

global___GenericParserCommon = GenericParserCommon

@typing.final
class AuditTrailsV1Parser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AuditTrailsV1Parser = AuditTrailsV1Parser

@typing.final
class CloudLoggingParser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CloudLoggingParser = CloudLoggingParser



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/export.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/logging/v1/export.proto\x12\x17yandex.cloud.logging.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1dyandex/cloud/validation.proto\"\xd2\x02\n\x06\x45xport\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12;\n\x06labels\x18\x07 \x03(\x0b\x32+.yandex.cloud.logging.v1.Export.LabelsEntry\x12\x10\n\x08group_id\x18\x08 \x01(\t\x12\x0f\n\x07sink_id\x18\t \x01(\t\x12\x35\n\x06params\x18\n \x01(\x0b\x32%.yandex.cloud.logging.v1.ExportParams\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n\x0c\x45xportParams\x12)\n\x0eresource_types\x18\x01 \x03(\tB\x11\x82\xc8\x31\x05<=100\x8a\xc8\x31\x04<=63\x12\'\n\x0cresource_ids\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05<=100\x8a\xc8\x31\x04<=63\x12\'\n\x0cstream_names\x18\x03 \x03(\tB\x11\x82\xc8\x31\x05<=100\x8a\xc8\x31\x04<=63\x12\x41\n\x06levels\x18\x04 \x03(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\x08\x82\xc8\x31\x04<=10\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000Bb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.export_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _EXPORT_LABELSENTRY._options = None
  _EXPORT_LABELSENTRY._serialized_options = b'8\001'
  _EXPORTPARAMS.fields_by_name['resource_types']._options = None
  _EXPORTPARAMS.fields_by_name['resource_types']._serialized_options = b'\202\3101\005<=100\212\3101\004<=63'
  _EXPORTPARAMS.fields_by_name['resource_ids']._options = None
  _EXPORTPARAMS.fields_by_name['resource_ids']._serialized_options = b'\202\3101\005<=100\212\3101\004<=63'
  _EXPORTPARAMS.fields_by_name['stream_names']._options = None
  _EXPORTPARAMS.fields_by_name['stream_names']._serialized_options = b'\202\3101\005<=100\212\3101\004<=63'
  _EXPORTPARAMS.fields_by_name['levels']._options = None
  _EXPORTPARAMS.fields_by_name['levels']._serialized_options = b'\202\3101\004<=10'
  _EXPORTPARAMS.fields_by_name['filter']._options = None
  _EXPORTPARAMS.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_EXPORT']._serialized_start=171
  _globals['_EXPORT']._serialized_end=509
  _globals['_EXPORT_LABELSENTRY']._serialized_start=464
  _globals['_EXPORT_LABELSENTRY']._serialized_end=509
  _globals['_EXPORTPARAMS']._serialized_start=512
  _globals['_EXPORTPARAMS']._serialized_end=746
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/marketplace/metering/v1/product_usage_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.marketplace.metering.v1 import usage_record_pb2 as yandex_dot_cloud_dot_marketplace_dot_metering_dot_v1_dot_usage__record__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@yandex/cloud/marketplace/metering/v1/product_usage_service.proto\x12$yandex.cloud.marketplace.metering.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x37yandex/cloud/marketplace/metering/v1/usage_record.proto\"\xa3\x01\n\x11WriteUsageRequest\x12\x0f\n\x07\x64ry_run\x18\x01 \x01(\x08\x12)\n\x13product_instance_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12R\n\rusage_records\x18\x03 \x03(\x0b\x32\x31.yandex.cloud.marketplace.metering.v1.UsageRecordB\x08\x82\xc8\x31\x04\x31-25\"\xae\x01\n\x12WriteUsageResponse\x12K\n\x08\x61\x63\x63\x65pted\x18\x01 \x03(\x0b\x32\x39.yandex.cloud.marketplace.metering.v1.AcceptedUsageRecord\x12K\n\x08rejected\x18\x02 \x03(\x0b\x32\x39.yandex.cloud.marketplace.metering.v1.RejectedUsageRecord2\xca\x01\n\x13ProductUsageService\x12\xb2\x01\n\x05Write\x12\x37.yandex.cloud.marketplace.metering.v1.WriteUsageRequest\x1a\x38.yandex.cloud.marketplace.metering.v1.WriteUsageResponse\"6\x82\xd3\xe4\x93\x02\x30\"+/marketplace/metering/v1/productUsage/write:\x01*B}\n(yandex.cloud.api.marketplace.metering.v1ZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/metering/v1;meteringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.metering.v1.product_usage_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.marketplace.metering.v1ZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/metering/v1;metering'
  _WRITEUSAGEREQUEST.fields_by_name['product_instance_id']._options = None
  _WRITEUSAGEREQUEST.fields_by_name['product_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _WRITEUSAGEREQUEST.fields_by_name['usage_records']._options = None
  _WRITEUSAGEREQUEST.fields_by_name['usage_records']._serialized_options = b'\202\3101\0041-25'
  _PRODUCTUSAGESERVICE.methods_by_name['Write']._options = None
  _PRODUCTUSAGESERVICE.methods_by_name['Write']._serialized_options = b'\202\323\344\223\0020\"+/marketplace/metering/v1/productUsage/write:\001*'
  _globals['_WRITEUSAGEREQUEST']._serialized_start=225
  _globals['_WRITEUSAGEREQUEST']._serialized_end=388
  _globals['_WRITEUSAGERESPONSE']._serialized_start=391
  _globals['_WRITEUSAGERESPONSE']._serialized_end=565
  _globals['_PRODUCTUSAGESERVICE']._serialized_start=568
  _globals['_PRODUCTUSAGESERVICE']._serialized_end=770
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dataproc/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.dataproc.v1 import cluster_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_cluster__pb2
from yandex.cloud.dataproc.v1 import common_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2
from yandex.cloud.dataproc.v1 import subcluster_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/dataproc/v1/cluster_service.proto\x12\x18yandex.cloud.dataproc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/dataproc/v1/cluster.proto\x1a%yandex/cloud/dataproc/v1/common.proto\x1a)yandex/cloud/dataproc/v1/subcluster.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"d\n\x14ListClustersResponse\x12\x33\n\x08\x63lusters\x18\x01 \x03(\x0b\x32!.yandex.cloud.dataproc.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe1\x02\n\x1a\x43reateSubclusterConfigSpec\x12/\n\x04name\x18\x01 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x32\n\x04role\x18\x02 \x01(\x0e\x32\x1e.yandex.cloud.dataproc.v1.RoleB\x04\xe8\xc7\x31\x01\x12<\n\tresources\x18\x03 \x01(\x0b\x32#.yandex.cloud.dataproc.v1.ResourcesB\x04\xe8\xc7\x31\x01\x12\x1f\n\tsubnet_id\x18\x04 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x0bhosts_count\x18\x05 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x18\n\x10\x61ssign_public_ip\x18\x06 \x01(\x08\x12G\n\x12\x61utoscaling_config\x18\x07 \x01(\x0b\x32+.yandex.cloud.dataproc.v1.AutoscalingConfig\"\xf8\x01\n\x1aUpdateSubclusterConfigSpec\x12\n\n\x02id\x18\x01 \x01(\t\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x36\n\tresources\x18\x03 \x01(\x0b\x32#.yandex.cloud.dataproc.v1.Resources\x12\x1c\n\x0bhosts_count\x18\x04 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12G\n\x12\x61utoscaling_config\x18\x05 \x01(\x0b\x32+.yandex.cloud.dataproc.v1.AutoscalingConfig\"\xb5\x01\n\x17\x43reateClusterConfigSpec\x12\x12\n\nversion_id\x18\x01 \x01(\t\x12\x36\n\x06hadoop\x18\x02 \x01(\x0b\x32&.yandex.cloud.dataproc.v1.HadoopConfig\x12N\n\x10subclusters_spec\x18\x03 \x03(\x0b\x32\x34.yandex.cloud.dataproc.v1.CreateSubclusterConfigSpec\"\xa1\x01\n\x17UpdateClusterConfigSpec\x12N\n\x10subclusters_spec\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.dataproc.v1.UpdateSubclusterConfigSpec\x12\x36\n\x06hadoop\x18\x02 \x01(\x0b\x32&.yandex.cloud.dataproc.v1.HadoopConfig\"\xa3\x05\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x87\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.dataproc.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12L\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.dataproc.v1.CreateClusterConfigSpecB\x04\xe8\xc7\x31\x01\x12\x1d\n\x07zone_id\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\x12service_account_id\x18\x08 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0e\n\x06\x62ucket\x18\t \x01(\t\x12\x10\n\x08ui_proxy\x18\n \x01(\x08\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x16\n\x0ehost_group_ids\x18\x0c \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\r \x01(\x08\x12\x14\n\x0clog_group_id\x18\x0e \x01(\t\x12\x42\n\x0b\x65nvironment\x18\x0f \x01(\x0e\x32-.yandex.cloud.dataproc.v1.Cluster.Environment\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x06\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xef\x04\n\x14UpdateClusterRequest\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x87\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.dataproc.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x46\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32\x31.yandex.cloud.dataproc.v1.UpdateClusterConfigSpec\x12/\n\x04name\x18\x06 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x08 \x01(\t\x12)\n\x14\x64\x65\x63ommission_timeout\x18\t \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12\x10\n\x08ui_proxy\x18\n \x01(\x08\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x12\x14\n\x0clog_group_id\x18\r \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x14\x64\x65\x63ommission_timeout\x18\x02 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"a\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x14\x64\x65\x63ommission_timeout\x18\x02 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x91\x01\n\x17ListClusterHostsRequest\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"b\n\x18ListClusterHostsResponse\x12-\n\x05hosts\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.dataproc.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"2\n\x12ListUILinksRequest\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"#\n\x06UILink\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"F\n\x13ListUILinksResponse\x12/\n\x05links\x18\x01 \x03(\x0b\x32 .yandex.cloud.dataproc.v1.UILink2\x91\r\n\x0e\x43lusterService\x12\x81\x01\n\x03Get\x12+.yandex.cloud.dataproc.v1.GetClusterRequest\x1a!.yandex.cloud.dataproc.v1.Cluster\"*\x82\xd3\xe4\x93\x02$\x12\"/dataproc/v1/clusters/{cluster_id}\x12\x84\x01\n\x04List\x12-.yandex.cloud.dataproc.v1.ListClustersRequest\x1a..yandex.cloud.dataproc.v1.ListClustersResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/dataproc/v1/clusters\x12\xa1\x01\n\x06\x43reate\x12..yandex.cloud.dataproc.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1a\"\x15/dataproc/v1/clusters:\x01*\x12\xae\x01\n\x06Update\x12..yandex.cloud.dataproc.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"Q\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\'2\"/dataproc/v1/clusters/{cluster_id}:\x01*\x12\xb9\x01\n\x06\x44\x65lete\x12..yandex.cloud.dataproc.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$*\"/dataproc/v1/clusters/{cluster_id}\x12\xae\x01\n\x05Start\x12-.yandex.cloud.dataproc.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02*\"(/dataproc/v1/clusters/{cluster_id}:start\x12\xad\x01\n\x04Stop\x12,.yandex.cloud.dataproc.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,\"\'/dataproc/v1/clusters/{cluster_id}:stop:\x01*\x12\xb8\x01\n\x0eListOperations\x12\x36.yandex.cloud.dataproc.v1.ListClusterOperationsRequest\x1a\x37.yandex.cloud.dataproc.v1.ListClusterOperationsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/dataproc/v1/clusters/{cluster_id}/operations\x12\xa4\x01\n\tListHosts\x12\x31.yandex.cloud.dataproc.v1.ListClusterHostsRequest\x1a\x32.yandex.cloud.dataproc.v1.ListClusterHostsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/dataproc/v1/clusters/{cluster_id}/hosts\x12\x9f\x01\n\x0bListUILinks\x12,.yandex.cloud.dataproc.v1.ListUILinksRequest\x1a-.yandex.cloud.dataproc.v1.ListUILinksResponse\"3\x82\xd3\xe4\x93\x02-\x12+/dataproc/v1/clusters/{cluster_id}/ui_linksBe\n\x1cyandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataprocb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034yandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataproc'
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATESUBCLUSTERCONFIGSPEC.fields_by_name['name']._options = None
  _CREATESUBCLUSTERCONFIGSPEC.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATESUBCLUSTERCONFIGSPEC.fields_by_name['role']._options = None
  _CREATESUBCLUSTERCONFIGSPEC.fields_by_name['role']._serialized_options = b'\350\3071\001'
  _CREATESUBCLUSTERCONFIGSPEC.fields_by_name['resources']._options = None
  _CREATESUBCLUSTERCONFIGSPEC.fields_by_name['resources']._serialized_options = b'\350\3071\001'
  _CREATESUBCLUSTERCONFIGSPEC.fields_by_name['subnet_id']._options = None
  _CREATESUBCLUSTERCONFIGSPEC.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESUBCLUSTERCONFIGSPEC.fields_by_name['hosts_count']._options = None
  _CREATESUBCLUSTERCONFIGSPEC.fields_by_name['hosts_count']._serialized_options = b'\372\3071\003>=1'
  _UPDATESUBCLUSTERCONFIGSPEC.fields_by_name['name']._options = None
  _UPDATESUBCLUSTERCONFIGSPEC.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATESUBCLUSTERCONFIGSPEC.fields_by_name['hosts_count']._options = None
  _UPDATESUBCLUSTERCONFIGSPEC.fields_by_name['hosts_count']._serialized_options = b'\372\3071\003>=1'
  _CREATECLUSTERREQUEST_LABELSENTRY._options = None
  _CREATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['name']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATECLUSTERREQUEST.fields_by_name['description']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _CREATECLUSTERREQUEST.fields_by_name['config_spec']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _CREATECLUSTERREQUEST.fields_by_name['zone_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['service_account_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001'
  _UPDATECLUSTERREQUEST_LABELSENTRY._options = None
  _UPDATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATECLUSTERREQUEST.fields_by_name['decommission_timeout']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['decommission_timeout']._serialized_options = b'\372\3071\0070-86400'
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETECLUSTERREQUEST.fields_by_name['decommission_timeout']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['decommission_timeout']._serialized_options = b'\372\3071\0070-86400'
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPCLUSTERREQUEST.fields_by_name['decommission_timeout']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['decommission_timeout']._serialized_options = b'\372\3071\0070-86400'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\212\3101\004<=50'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTUILINKSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTUILINKSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\212\3101\004<=50'
  _CLUSTERSERVICE.methods_by_name['Get']._options = None
  _CLUSTERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002$\022\"/dataproc/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['List']._options = None
  _CLUSTERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/dataproc/v1/clusters'
  _CLUSTERSERVICE.methods_by_name['Create']._options = None
  _CLUSTERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002\032\"\025/dataproc/v1/clusters:\001*'
  _CLUSTERSERVICE.methods_by_name['Update']._options = None
  _CLUSTERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002\'2\"/dataproc/v1/clusters/{cluster_id}:\001*'
  _CLUSTERSERVICE.methods_by_name['Delete']._options = None
  _CLUSTERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002$*\"/dataproc/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['Start']._options = None
  _CLUSTERSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\002*\"(/dataproc/v1/clusters/{cluster_id}:start'
  _CLUSTERSERVICE.methods_by_name['Stop']._options = None
  _CLUSTERSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\002,\"\'/dataproc/v1/clusters/{cluster_id}:stop:\001*'
  _CLUSTERSERVICE.methods_by_name['ListOperations']._options = None
  _CLUSTERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002/\022-/dataproc/v1/clusters/{cluster_id}/operations'
  _CLUSTERSERVICE.methods_by_name['ListHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\002*\022(/dataproc/v1/clusters/{cluster_id}/hosts'
  _CLUSTERSERVICE.methods_by_name['ListUILinks']._options = None
  _CLUSTERSERVICE.methods_by_name['ListUILinks']._serialized_options = b'\202\323\344\223\002-\022+/dataproc/v1/clusters/{cluster_id}/ui_links'
  _globals['_GETCLUSTERREQUEST']._serialized_start=367
  _globals['_GETCLUSTERREQUEST']._serialized_end=420
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=423
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=567
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=569
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=669
  _globals['_CREATESUBCLUSTERCONFIGSPEC']._serialized_start=672
  _globals['_CREATESUBCLUSTERCONFIGSPEC']._serialized_end=1025
  _globals['_UPDATESUBCLUSTERCONFIGSPEC']._serialized_start=1028
  _globals['_UPDATESUBCLUSTERCONFIGSPEC']._serialized_end=1276
  _globals['_CREATECLUSTERCONFIGSPEC']._serialized_start=1279
  _globals['_CREATECLUSTERCONFIGSPEC']._serialized_end=1460
  _globals['_UPDATECLUSTERCONFIGSPEC']._serialized_start=1463
  _globals['_UPDATECLUSTERCONFIGSPEC']._serialized_end=1624
  _globals['_CREATECLUSTERREQUEST']._serialized_start=1627
  _globals['_CREATECLUSTERREQUEST']._serialized_end=2302
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=2251
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=2296
  _globals['_CREATECLUSTERMETADATA']._serialized_start=2304
  _globals['_CREATECLUSTERMETADATA']._serialized_end=2347
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=2350
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2973
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=2251
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=2296
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2975
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=3018
  _globals['_DELETECLUSTERREQUEST']._serialized_start=3020
  _globals['_DELETECLUSTERREQUEST']._serialized_end=3119
  _globals['_DELETECLUSTERMETADATA']._serialized_start=3121
  _globals['_DELETECLUSTERMETADATA']._serialized_end=3164
  _globals['_STARTCLUSTERREQUEST']._serialized_start=3166
  _globals['_STARTCLUSTERREQUEST']._serialized_end=3221
  _globals['_STARTCLUSTERMETADATA']._serialized_start=3223
  _globals['_STARTCLUSTERMETADATA']._serialized_end=3265
  _globals['_STOPCLUSTERREQUEST']._serialized_start=3267
  _globals['_STOPCLUSTERREQUEST']._serialized_end=3364
  _globals['_STOPCLUSTERMETADATA']._serialized_start=3366
  _globals['_STOPCLUSTERMETADATA']._serialized_end=3407
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=3409
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=3535
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=3537
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=3648
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=3651
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=3796
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=3798
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=3896
  _globals['_LISTUILINKSREQUEST']._serialized_start=3898
  _globals['_LISTUILINKSREQUEST']._serialized_end=3948
  _globals['_UILINK']._serialized_start=3950
  _globals['_UILINK']._serialized_end=3985
  _globals['_LISTUILINKSRESPONSE']._serialized_start=3987
  _globals['_LISTUILINKSRESPONSE']._serialized_end=4057
  _globals['_CLUSTERSERVICE']._serialized_start=4060
  _globals['_CLUSTERSERVICE']._serialized_end=5741
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/project_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.speechsense.v1 import project_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/speechsense/v1/project_service.proto\x12\x1byandex.cloud.speechsense.v1\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a)yandex/cloud/speechsense/v1/project.proto\"\x8b\x01\n\x14\x43reateProjectRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x39\n\x07\x66ilters\x18\x04 \x03(\x0b\x32(.yandex.cloud.speechsense.v1.FieldFilter\"#\n\x15\x43reateProjectMetadata\x12\n\n\x02id\x18\x01 \x01(\t2\x97\x01\n\x0eProjectService\x12\x84\x01\n\x06\x43reate\x12\x31.yandex.cloud.speechsense.v1.CreateProjectRequest\x1a!.yandex.cloud.operation.Operation\"$\xb2\xd2* \n\x15\x43reateProjectMetadata\x12\x07ProjectB\x83\x01\n\x1fyandex.cloud.api.speechsense.v1B\x13ProjectServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.project_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\023ProjectServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _PROJECTSERVICE.methods_by_name['Create']._options = None
  _PROJECTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateProjectMetadata\022\007Project'
  _globals['_CREATEPROJECTREQUEST']._serialized_start=200
  _globals['_CREATEPROJECTREQUEST']._serialized_end=339
  _globals['_CREATEPROJECTMETADATA']._serialized_start=341
  _globals['_CREATEPROJECTMETADATA']._serialized_end=376
  _globals['_PROJECTSERVICE']._serialized_start=379
  _globals['_PROJECTSERVICE']._serialized_end=530
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TuningTypeLora(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RANK_FIELD_NUMBER: builtins.int
    ALPHA_FIELD_NUMBER: builtins.int
    INITIALIZATION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    rank: builtins.int
    alpha: builtins.float
    initialization: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        rank: builtins.int = ...,
        alpha: builtins.float = ...,
        initialization: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alpha", b"alpha", "initialization", b"initialization", "rank", b"rank", "type", b"type"]) -> None: ...

global___TuningTypeLora = TuningTypeLora

@typing.final
class TuningTypePromptTune(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIRTUAL_TOKENS_FIELD_NUMBER: builtins.int
    virtual_tokens: builtins.int
    def __init__(
        self,
        *,
        virtual_tokens: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["virtual_tokens", b"virtual_tokens"]) -> None: ...

global___TuningTypePromptTune = TuningTypePromptTune
